import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format,
  scale
} from 'd3';

const xAxisLabelText = 'Population';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = chartJson => {
  var tooltip = d3.select("body")
      .append("div")
      .style("position", "absolute")
      .style("z-index", "10")
      .style("visibility", "hidden")
      .style("background", "#fff")
      .text("a simple tooltip");
  const data = chartJson.data;
  const xValue = d => d[chartJson.xAxisKey];
  const yValue = d => d[chartJson.yAxisKey];
  const margin = { top: 50, right: 40, bottom: 77, left: 270 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const radius = Math.min(width, height) / 2;
  const color = d3.scaleOrdinal(d3.schemeCategory10);
  const g = svg.append("g")
  .data([data]) 
  .attr("transform", "translate(" + width / 2 + "," + height / 2 + ")");
  
  var arc = d3.arc()
					.innerRadius(0)
					.outerRadius(radius);

    var pie = d3.pie()           
        .value(function(d) { return parseInt(d.population); });    

    var arcs = g.selectAll("g.slice")     
        .data(pie)                        
        .enter()                           
            .append("svg:g")               
                .attr("class", "slice"); 
  
        var section = arcs.append("svg:path")
                .attr("fill", function(d, i) { return color(i); } ) 
                .attr("d", arc);                                    

        arcs.append("svg:text")                                     //add a label to each slice
                .attr("transform", function(d) {                    
                d.innerRadius = 0;
                d.outerRadius = radius;
                return "translate(" + arc.centroid(d) + ")";  
            })
            .attr("text-anchor", "middle")                         
            .text(function(d, i) { return data[i].country; }); 
  
  
  
  if(chartJson.clickEvent){
  	section.on("click", (data)=>{
      console.log(data)
      alert(chartJson.yAxisLabel+ " : " +yValue(data.data) + ", "+chartJson.xAxisLabel  + " : " + xValue(data.data)); return tooltip.style("visibility", "visible");
    })
  }
   if(chartJson.hoverEvent){
  	section.on("mouseover", (data)=>{
      tooltip.text(chartJson.yAxisLabel+ " : " +yValue(data.data) + ", "+chartJson.xAxisLabel  + " : " + xValue(data.data)); return tooltip.style("visibility", "visible");
    })
 
    .on("mousemove", ()=>{return tooltip.style("top", (d3.event.pageY-10)+"px").style("left",(d3.event.pageX+10)+"px");})
    .on("mouseout", ()=>{
      return tooltip.style("visibility", "hidden");
    }); 
  } 
  
};

csv('data.csv').then(data => {
  // set the chart configration here
  // css will be set via theme
  // need to use generic class across the charts
  // chart title will be show out of chart svg
  console.log(data)
  const chartJson = {
    chartType: 'bar',
    chartTitle: 'Top 10 Most Populous Countries',
  	data: data,
    xAxisKey : 'population',
    yAxisKey: 'country',
    xAxisLabel: 'Population',
    yAxisLabel: 'Country',
    xAxisLabelVisible: false,
    yAxisLabelVisible: false,
    verticleGridLine: false,
    horizontalGridLine: false,
    clickEvent: true,
    hoverEvent: true,
  };
  render(chartJson);
});